@@ -20,24 +20,24 @@
 #include <gtk/gtk.h>
 
 #include <sys/stat.h>
-#include <stdlib.h> // Sometimes this might have to be included explicitly.
-#include <string.h> // Sometimes this might have to be included explicitly.
+#include <stdlib.h> // May need to be included explicitly in some environments.
+#include <string.h> // May need to be included explicitly in some environments.
 
 #include "declarations_definitions_and_enumerations.h"
 #include "auxiliary.h"
 
 /*
 
-    -------------------------------------------------------------------
-      GENERAL - Auxiliary functions not necessarily bound to Kickshaw
-    -------------------------------------------------------------------
+    ------------------------------------------------------------------------
+       GENERAL — Auxiliary functions not necessarily specific to Kickshaw
+    ------------------------------------------------------------------------
 
 */
 
 
 /* 
 
-    Version comparison function used in case that glibc is not installed.
+    Version comparison function used when glibc is not installed.
 
 */
 
@@ -61,7 +61,7 @@ gint8 strverscmp_nonglibc (const gchar *version1, const gchar *version2) {
 
 /* 
 
-    Expands a row by retrieving the required path from a passed iterator.
+    Expands a row using the path obtained from the given iterator.
 
 */
 
@@ -74,15 +74,15 @@ void expand_row_from_iter (GtkTreeIter *local_iter)
 
 /* 
 
-   Extracts a substring from a string by using a regular expression.
+   Extracts a substring from a string using a regular expression
 
-   This function returns a newly-allocated string that should be freed with g_free () after use.
+   Returns a newly allocated string that must be freed with g_free() after use.
 
 */
 
 gchar *extract_substring_via_regex (const gchar *string, const gchar *regex_str)
 {
-    // No compile and match options, no return location for a GError.
+    // No compile or match options; no GError return location.
     g_autoptr(GRegex) regex = g_regex_new (regex_str, 0, 0, NULL);
     g_autoptr(GMatchInfo) match_info; // match_info is created even if g_regex_match returns FALSE.
     gchar *match;
@@ -95,7 +95,7 @@ gchar *extract_substring_via_regex (const gchar *string, const gchar *regex_str)
 
 /* 
 
-    Frees dyn. alloc. memory of all strings of a static string array.
+    Frees dynamically allocated memory for all strings in a static string array.
 
 */
 
@@ -116,9 +116,9 @@ void free_elements_of_static_string_array (      gchar    **string_array,
 
 /* 
 
-    Retrieves the current font so that it can be used with a Pango font description.
+    Retrieves the current font so it can be used with a Pango font description.
 
-    This function returns a newly-allocated string that should be freed with g_free () after use.
+    Returns a newly allocated string that must be freed with g_free() after use.
 
 */
 
@@ -135,7 +135,7 @@ gchar *get_font_name (void)
 
 /* 
 
-    Retrieves the current font size so that the size of the icon images can be adjusted to it.
+    Retrieves the current font size so icon image sizes can be adjusted accordingly.
 
 */
 
@@ -153,9 +153,9 @@ guint get_font_size (void)
 
 /* 
 
-    Returns the time of the last modification of an icon image file as an RFC 3339 encoded string.
+    Returns the time of last modification of an icon image file as an RFC 3339–encoded string.
 
-    Since memory has been allocated for it, the string should be freed with g_free () after use.
+    The returned string is dynamically allocated and must be freed with g_free() after use.
 
 */
 
@@ -192,7 +192,7 @@ gchar *get_modification_time_for_icon (const gchar *icon_path)
 
 /* 
 
-    Sets an iterator for the toplevel of a given path.
+    SetS an iterator to the top-level node of a given path.
 
 */
 
@@ -206,8 +206,8 @@ void get_toplevel_iter_from_path (GtkTreeIter *local_iter,
 
 /* 
 
-    Short replacement for the check if a string equals to one of several values
-    (strcmp (x,y) == 0 || strcmp (x,z) == 0).
+    Short helper to check whether a string equals one of several values
+    (strcmp(x, y) == 0 || strcmp(x, z) == 0).
 
 */
 
@@ -256,8 +256,8 @@ void add_elements_to_ptr_array (GPtrArray *array, ...)
 
     An equivalent of rm -rf.
 
-    This function makes use of recursion. It is also a particularly suitable case 
-    for using the g_autoptr () macro to keep the code tidy.
+    This function uses recursion. It is also a particularly suitable case 
+    for using the g_autoptr() macro to keep the code tidy.
 
 */
 
@@ -288,8 +288,9 @@ gboolean rm_rf (GFile         *file,
 
 /*
 
-    Retrieves a text that is stored inside a GResource element.
-    The memory for the returned string has been dynamically allocated and must be freed after use.
+    Retrieves text stored in a GResource element.
+
+    The returned string is dynamically allocated and must be freed after use.
 
 */
 
@@ -305,15 +306,15 @@ gchar *get_txt_from_resources (      GResource *resources,
 
 /* 
 
-    --------------------------------------------------------------------
-      KICKSHAW-SPECIFIC - Auxiliary functions for use in Kickshaw only
-    --------------------------------------------------------------------
+    ----------------------------------------------------------------------
+       KICKSHAW-SPECIFIC — Auxiliary functions for use in Kickshaw only
+    ----------------------------------------------------------------------
 
 */
 
 /*
 
-    A save way to set the values of several bits of the settings bit field
+    A safe way to set the values of several bits of the settings bit field.
 
 */
 
@@ -413,13 +414,13 @@ void delete_autosave (void)
 
 /* 
 
-    Refreshes the txt_fields array with the values of the currently selected row.
+    Refreshes the txt_fields array with values from the currently selected row.
 
 */
 
 void repopulate_txt_fields_array (void)
 {
-    // FALSE = Don't set array elements to NULL after freeing.
+    // FALSE = don't set array elements to NULL after freeing.
     free_elements_of_static_string_array (ks.txt_fields, NUMBER_OF_TXT_FIELDS, FALSE);
     gtk_tree_model_get (ks.ts_model, &ks.iter, 
                         TS_ICON_PATH, &ks.txt_fields[ICON_PATH_TXT],
@@ -434,7 +435,7 @@ void repopulate_txt_fields_array (void)
 
 /* 
 
-    Creates a new label with some formattings.
+    Creates a new label with formatting.
 
 */
 
@@ -447,13 +448,13 @@ GtkWidget *new_label_with_formattings (const gchar    *label_txt,
 
 /* 
 
-    Convenience function for the creation of a dialog window.
+    Convenience function for creating a dialog window.
 
-    The dialog can have up to three buttons. If less than three are needed, 
-    the "button_txt_2" and/or "button_txt_3" argument should be set to NULL.
-    If something else than a label text shall be added to the content area, 
-    the "show_immediately" argument should be set to DONT_SHOW_IMMEDIATELY (=FALSE). 
-    gtk_widget_show_all () should be called then after all additional widgets have been added to the content area.
+    The dialog can have up to three buttons. If fewer are needed, 
+    set the "button_txt_2" and/or "button_txt_3" argument to NULL.
+    If content other than a label should be added to the content area, 
+    set "show_immediately" to DONT_SHOW_IMMEDIATELY (= FALSE). 
+    Then call gtk_widget_show_all() after all additional widgets have been added to the content area.
 
 */
 
@@ -516,7 +517,7 @@ void set_header_bar_for_dialog (      GtkWidget *dialog,
 
 /*
 
-    Shows a simple dialog for noticing purposes.
+    Shows a simple informational dialog.
 
 */
 
@@ -535,7 +536,7 @@ void show_message_dialog (const gchar *dialog_title,
 
 /* 
 
-    Creates a file dialog for opening a new and saving an existing menu.
+    Creates a file dialog for opening or saving a menu.
 
 */
 
@@ -546,13 +547,13 @@ void create_file_dialog (      GtkWidget **dialog,
     g_autoptr(GFile) menu_folder = g_file_new_for_path (menu_folder_str);
     GtkFileFilter *file_filter;
 
-    // Translation note: the verb "Open"
+    // Translation note: the verb "Open".
     *dialog = gtk_file_chooser_dialog_new ((open) ? _("Open Openbox Menu File") : 
 	                                                _("Save Openbox Menu File As…"), 
                                            GTK_WINDOW (ks.window),
                                            (open) ? GTK_FILE_CHOOSER_ACTION_OPEN : GTK_FILE_CHOOSER_ACTION_SAVE, 
                                            C_("Cancel|File Dialogue", "_Cancel"), GTK_RESPONSE_CANCEL,
-										   // Translation note: the verb "Open"
+										   // Translation note: the verb "Open".
                                            (open) ? _("_Open") :
             										_("_Save"), GTK_RESPONSE_ACCEPT,
                                            NULL);
@@ -569,14 +570,14 @@ void create_file_dialog (      GtkWidget **dialog,
 
 /*
 
-    Determines if a dark theme or a theme with a background/gradient is active
+    Determines whether a dark theme or a theme with a background/gradient is active.
 
 */
 
 void determine_theme_type (void)
 {
     GtkStyleContext *window_context = gtk_widget_get_style_context (ks.window);
-    g_autoptr(cairo_pattern_t) background_image = NULL; // Default
+    g_autoptr(cairo_pattern_t) background_image = NULL; // Default value.
 
     gtk_style_context_get (window_context, GTK_STATE_FLAG_NORMAL, GTK_STYLE_PROPERTY_BACKGROUND_IMAGE, &background_image, NULL);
 
@@ -612,18 +613,20 @@ void determine_theme_type (void)
     
         ks.blue_hue = (ks.bg_image_or_gradient) ? "blue" : ((!ks.dark_theme) ? "darkblue" : "lightblue");
 
-        // Translation note: If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Label”), not the definite one (“The Label”).
+        // Translation note: If the target language distinguishes between definite and indefinite forms, 
+        // please use the indefinite form (“Label”), not the definite one (“The Label”).
         g_string_printf (ks.label_field_txt, _(" Label (<span foreground='%s'>*</span>): "), ks.red_hue);
         if (G_UNLIKELY (g_slist_find_custom (ks.menu_ids, "", (GCompareFunc) strcmp))) {
-            // Translation note: If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Menu ID”), not the definite one (“The Menu ID”).
+            // Translation note: If the target language distinguishes between definite and indefinite forms, 
+            // please use the indefinite form (“Menu ID”), not the definite one (“The Menu ID”).
             g_string_printf (ks.menu_ID_field_txt, _(" Menu ID (<span foreground='%s'>*</span>): "), ks.blue_hue);
         }
         else {
-            // Translation note: If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Menu ID”), not the definite one (“The Menu ID”).
+            // Translation note: If the target language distinguishes between definite and indefinite forms, 
+            // please use the indefinite form (“Menu ID”), not the definite one (“The Menu ID”).
             g_string_assign (ks.menu_ID_field_txt, _(" Menu ID: "));
         }
-        // In the case that a right-to-left script is used the following three need the &#8207 entity inserted, 
-        // because otherwise the colon will not set to the left of the text.
+        // For right-to-left scripts, the following three require the &#8207 entity so the colon appears on the correct side.
         // For the label texts above it works without, because there are translations.
         g_string_printf (ks.execute_field_txt, "%s Execute (<span foreground='%s'>*</span>): ", right_to_left, ks.red_hue);
         g_string_printf (ks.prompt_field_txt, "%s Prompt (<span foreground='%s'>*</span>): ", right_to_left, ks.red_hue);
@@ -632,7 +635,7 @@ void determine_theme_type (void)
         g_string_printf (ks.mandatory_empty_string_txt, "(<span foreground='%s'>*</span>) = %s; "
                                                         "(<span foreground='%s'>*</span>) = %s",
                                                         ks.red_hue, _("mandatory"), 
-														// Translation note: "mand. as" means "mandatory because" here 
+														// Translation note: "mand. as" means "mandatory because" here.
 														ks.blue_hue, _("mand. as empty-string menu ID exists"));
         g_string_printf (ks.double_menu_id_label_txt, " <span foreground='%s'>!!</span> %s <span foreground='%s'>!!</span> ", 
                                                       ks.red_hue,  _("Menu ID already exists "), ks.red_hue);
@@ -694,26 +697,25 @@ void create_invalid_icon_imgs (void)
 
 /* 
 
-    Checks expansion statuses of nodes to determine 
-    - how to set the sensivity of the application menu items and toolbar buttons for the expansion and collapse of all nodes.
+    Checks expansion states of nodes to determine:
+    - how to set the sensitivity of application menu items and toolbar buttons for expanding/collapsing all nodes.
 
-    In this case this function has been called after a selection.
-    It is only necessary to check whether there is at least one expanded and collapsed node, 
-    regardless of their position inside the treeview.
-    at_least_one_is_expanded and at_least_one_is_collapsed are set to TRUE, if the respective conditions apply.
+    In this case the function is called after a selection.
+    It suffices to check whether there is at least one expanded and one collapsed node,
+    regardless of their position in the tree view.
+    at_least_one_is_expanded and at_least_one_is_collapsed are set to TRUE if the respective conditions apply.
 
     - which expansion and collapse options to add to the context menu 
-    (expand recursively, expand only immediate children and collapse).
+      (expand recursively, expand only immediate children, and collapse).
 
-    In this case this function has been called after one or more rows, all of them containing at least one child, 
-    were rightlicked.
-    It has to be checked whether an immediate child of a row is expanded. If this applies to one of the selected rows 
-    or at least one of the selected rows is currently not expanded, the option to expand only the immediate children is 
-    added later to the context menu.
-    The second check is for whether there is at least one collapsed node, since if one is collapsed it should 
-    be possible to recursively expand all nodes. To determine whether the collapse option should be added it is 
-    sufficient to check if the root node is expanded, which is not done here.
-    at_least_one_imd_ch_is_collapsed and at_least_one_is_collapsed are set to TRUE, if the respective conditions apply.
+    In this case the function is called after one or more rows with at least one child each were right-clicked.
+    It must be checked whether an immediate child of a row is expanded. If this applies to one of the selected rows,
+    or at least one of the selected rows is currently not expanded, the option to expand only immediate children is
+    added to the context menu later.
+    The second check determines whether there is at least one collapsed node; if one is collapsed, it should be
+    possible to expand all nodes recursively. Whether the collapse option should be added can be decided by checking
+    if the root node is expanded (not done here).
+    at_least_one_imd_ch_is_collapsed and at_least_one_is_collapsed are set to TRUE if the respective conditions apply.
 
 */
 
@@ -723,11 +725,11 @@ gboolean check_expansion_statuses_of_nodes (GtkTreeModel *foreach_or_filter_mode
                                             gpointer      expansion_statuses_of_nodes_ptr)
 {
     b_ExpansionStatuses *expansion_statuses_of_nodes = (b_ExpansionStatuses *) expansion_statuses_of_nodes_ptr;
-    g_autoptr(GtkTreePath) model_path = NULL; // Default
+    g_autoptr(GtkTreePath) model_path = NULL; // Default value.
 
     if (gtk_tree_model_iter_has_child (foreach_or_filter_model, foreach_or_filter_iter)) {
         if (ks.ts_model != foreach_or_filter_model) { // = filter, called from create_context_menu ()
-            // The path of the model, not filter model, is needed to check whether the row is expanded.
+            // The path of the underlying model, not the filter model, is needed to check whether the row is selected.
             model_path = gtk_tree_model_filter_convert_path_to_child_path ((GtkTreeModelFilter *) foreach_or_filter_model, 
                                                                            foreach_or_filter_path);
         }
@@ -745,7 +747,7 @@ gboolean check_expansion_statuses_of_nodes (GtkTreeModel *foreach_or_filter_mode
         }
     }
 
-    // Iterate only as long as not for all queried statuses a positive match has been found.
+    // Iterate only until all queried statuses have a positive match.
     return (((model_path) ? expansion_statuses_of_nodes->at_least_one_imd_ch_is_expanded : 
                             expansion_statuses_of_nodes->at_least_one_is_expanded) && 
                             expansion_statuses_of_nodes->at_least_one_is_collapsed);
@@ -753,7 +755,7 @@ gboolean check_expansion_statuses_of_nodes (GtkTreeModel *foreach_or_filter_mode
 
 /* 
 
-    Checks for existing options of an Execute action or startupnotify option.
+    Checks for existing options of an Execute action or a startupnotify option.
 
 */
 
@@ -806,7 +808,7 @@ gboolean check_if_invisible_descendant_exists (              GtkTreeModel *filte
 /* 
 
     Looks for invisible ancestors of a given path and
-    returns the status of the elements visibility column for the first found one.
+    returns the visibility status of the first one found.
 
 */
 
@@ -864,7 +866,7 @@ gboolean add_icon_occurrence_to_list (G_GNUC_UNUSED GtkTreeModel *foreach_model,
 
 /* 
 
-    (De)activates all other column check buttons if "All columns" is (un)selected. 
+    Activates or deactivates all other column check buttons when "All columns" is selected or unselected. 
 
 */
 
@@ -904,7 +906,8 @@ void find_in_columns_management (const gboolean    origin_is_fr,
 
 /*
 
-    If regular expressions are activated, check if the regular expression is valid. If not, an error message will be displayed.
+    If regular expressions are enabled, checks whether the regular expression is valid.
+    If not, an error message will be displayed.
 
 */
 
@@ -929,8 +932,8 @@ gboolean check_if_regex_is_valid (GtkWidget *regex_checkbox, GtkWidget *entry_fi
 
 /* 
 
-    Gives widget a red border (entry field) or background color (checkbox) to indicate 
-    that a mandatory input or setting is missing or there is something wrong with existing data. 
+    Gives a widget a red border (entry field) or background color (checkbox) to indicate 
+    that a mandatory input or setting is missing, or there is something wrong with existing data. 
 
 */
 
@@ -950,7 +953,7 @@ void visually_indicate_request_for_user_intervention (GtkWidget      *widget,
 
 /*
 
-    Checks if Kickshaw is installed somewhere and returns the command suiting for a restart.
+    Checks whether Kickshaw is installed system-wide and returns the appropriate command for a restart.
 
 */
 
@@ -959,7 +962,7 @@ const gchar *installed_or_local (void)
     g_auto(GStrv) paths = g_strsplit (g_getenv ("PATH"), ":", -1);
     guint paths_idx = 0;
     struct stat sb;
-    const gchar *command = "./kickshaw"; // Default
+    const gchar *command = "./kickshaw"; // Default value.
 
     while (paths[paths_idx]) {
         g_autofree gchar *path_with_iconv = g_strconcat (paths[paths_idx], "/kickshaw", NULL);
