@@ -22,7 +22,7 @@
 #include "declarations_definitions_and_enumerations.h"
 #include "drag_and_drop.h"
 
-// DD = drag & drop, indicating that the enums are only used here
+// DD = drag & drop; indicates that these enums are used only in this file.
 enum { DD_SUBROWS_ICON_IMG, DD_SUBROWS_ICON_IMG_STATUS, DD_SUBROWS_ICON_MODIFICATION_TIME, DD_SUBROWS_ICON_PATH, 
        DD_SUBROWS_MENU_ELEMENT, DD_SUBROWS_TYPE, DD_SUBROWS_VALUE, DD_SUBROWS_MENU_ID, DD_SUBROWS_EXECUTE, 
        DD_SUBROWS_ELEMENT_VISIBILITY, DD_SUBROWS_EXPANSION_STATUS, DD_SUBROWS_CURRENT_PATH_DEPTH, DD_SUBROWS_MAX_PATH_DEPTH, 
@@ -35,7 +35,7 @@ static gboolean subrows_creation_auxiliary (GtkTreeModel  *filter_model,
 
 /* 
 
-    Allows a drop only under conditions which make sense.
+    Allows a drop only when it results in a valid placement.
 
 */
 
@@ -48,30 +48,30 @@ gboolean drag_motion_handler (G_GNUC_UNUSED GtkWidget      *widget,
 {
     GtkTreeViewDropPosition position;
 
-    g_autoptr(GtkTreePath) dest_path_drag_motion, dest_parent_path = NULL; // Default
+    g_autoptr(GtkTreePath) dest_path_drag_motion, dest_parent_path = NULL; // Default value.
     GtkTreeIter dest_parent_iter;
     g_autofree gchar *menu_element_dest_parent_txt = NULL, 
-                     *type_dest_parent_txt = NULL; // Defaults
+                     *type_dest_parent_txt = NULL; // Default values.
 
-    const gchar *statusbar_txt = NULL; // Default
+    const gchar *statusbar_txt = NULL; // Default value.
 
     GSList *source_paths_loop;
 
-    // Reset
+    // Reset the status bar if a message is currently shown
     if (ks.statusbar_msg_shown) {
-        gtk_statusbar_remove_all (GTK_STATUSBAR (ks.statusbar), 1); // Only one context (indicated by 1) with one message.
+        gtk_statusbar_remove_all (GTK_STATUSBAR (ks.statusbar), 1); // Single context (ID 1) with a single message.
         ks.statusbar_msg_shown = FALSE;
     }
 
     /*
-        The return value of gtk_tree_view_get_dest_row_at_pos is not needed here, since dest_path_drag_motion == NULL 
-        already indicates that the row has been dragged after the last row of the menu.
+        We ignore the return value of gtk_tree_view_get_dest_row_at_pos; a NULL dest_path_drag_motion
+        already indicates that the row was dragged after the last menu row.
     */ 
     gtk_tree_view_get_dest_row_at_pos (GTK_TREE_VIEW (ks.treeview), x, y, &dest_path_drag_motion, &position);
 
-    if (dest_path_drag_motion) { // = Not dragged after the last row of the menu.
+    if (dest_path_drag_motion) { // Not dropped after the last menu row.
         gint dest_path_depth = gtk_tree_path_get_depth (dest_path_drag_motion);
-        gboolean dropped_onto_row = FALSE; // Default
+        gboolean dropped_onto_row = FALSE; // Default value.
 
         if (position == GTK_TREE_VIEW_DROP_INTO_OR_BEFORE || position == GTK_TREE_VIEW_DROP_INTO_OR_AFTER) {
             gtk_tree_model_get_iter (ks.ts_model, &dest_parent_iter, dest_path_drag_motion);
@@ -115,7 +115,7 @@ gboolean drag_motion_handler (G_GNUC_UNUSED GtkWidget      *widget,
         source_parent_path = gtk_tree_path_copy (source_path_loop);
         gtk_tree_path_up (source_parent_path);
 
-        // Prevent that menus are dragged into themselves.
+        // Prevent dragging a menu into itself.
         if (STREQ (type_txt_loop, "menu") && dest_path_drag_motion && 
             gtk_tree_path_is_descendant (dest_path_drag_motion, source_path_loop)) {
             statusbar_txt = _("!!! Menus can't be dragged into themselves !!!");
@@ -123,8 +123,8 @@ gboolean drag_motion_handler (G_GNUC_UNUSED GtkWidget      *widget,
             break;
         }
 
-        // Prevent that menu elements are dragged to a place where they don't belong.
-        if ((type_dest_parent_txt && // Not dragged to toplevel
+        // Prevent dragging menu elements to invalid locations.
+        if ((type_dest_parent_txt && // Not dragged to top level
             element_visibility_txt_loop && !STREQ (type_dest_parent_txt, "menu")) || 
 
             (STREQ (type_txt_loop, "action") && !STREQ (type_dest_parent_txt, "item")) || 
@@ -148,7 +148,7 @@ gboolean drag_motion_handler (G_GNUC_UNUSED GtkWidget      *widget,
             break;
         }
 
-        // Prevent that Execute options are dragged inside the same Execute action if autosorting is activated.
+        // When autosorting is enabled, prevent moving Execute options within the same Execute action.
         if (ks.settings.autosort_options && streq_any (type_txt_loop, "option", "option block", NULL) && 
             streq_any (menu_element_dest_parent_txt, "Execute", "startupnotify", NULL) &&
             gtk_tree_path_compare (source_parent_path, dest_parent_path) == 0) {
@@ -163,7 +163,7 @@ gboolean drag_motion_handler (G_GNUC_UNUSED GtkWidget      *widget,
             gtk_tree_path_compare (source_parent_path, dest_parent_path) != 0) {
             for (gint ch_cnt = 0; ch_cnt < gtk_tree_model_iter_n_children (ks.ts_model, &dest_parent_iter); ++ch_cnt) {
                 GtkTreeIter option_iter_loop;
-                g_autofree gchar *menu_element_option_txt_loop; // Loop text for option_iter_loop.
+                g_autofree gchar *menu_element_option_txt_loop; // Text for option_iter_loop.
 
                 gtk_tree_model_iter_nth_child (ks.ts_model, &option_iter_loop, &dest_parent_iter, ch_cnt);
                 gtk_tree_model_get (ks.ts_model, &option_iter_loop, TS_MENU_ELEMENT, &menu_element_option_txt_loop, -1);
@@ -176,20 +176,20 @@ gboolean drag_motion_handler (G_GNUC_UNUSED GtkWidget      *widget,
         }
 
         /*
-            Prevent that a prompt option with a value other than "yes" or "no" 
-            is dragged into the actions "Exit" and "SessionLogout".
+            Prevent dragging a "prompt" option with a value other than "yes" or "no"
+            into the "Exit" or "SessionLogout" actions; only "yes" or "no" is valid.
         */
         if (STREQ (type_txt_loop, "option") && STREQ (menu_element_txt_loop, "prompt") && 
             streq_any (menu_element_dest_parent_txt, "Exit", "SessionLogout", NULL) && 
             !streq_any (value_txt_loop, "yes", "no", NULL)) {
-	        // Translation note: Do not translate the words "Prompt", "yes", "no"
+	        // Translation note: Do not translate the words "Prompt", "yes", "no".
             statusbar_txt = _("!!! Prompt option must have value \"yes\" or \"no\" !!!");
         }
     }
 
     if (statusbar_txt) {
         show_msg_in_statusbar (statusbar_txt);
-        gdk_drag_status (drag_context, 0, time); // Indicates that a drop will not be accepted.
+        gdk_drag_status (drag_context, 0, time); //  Signal that the drop is not accepted.
     }
 
     return (statusbar_txt != NULL);
@@ -197,7 +197,7 @@ gboolean drag_motion_handler (G_GNUC_UNUSED GtkWidget      *widget,
 
 /*
 
-    Resets the statusbar after dragging is abandoned.
+    Resets the status bar when dragging is abandoned.
 
 */
 
@@ -206,18 +206,17 @@ void drag_leave_handler (G_GNUC_UNUSED GtkWidget      *widget,
                          G_GNUC_UNUSED guint           time,
                          G_GNUC_UNUSED gpointer        user_data)
 {
-    gtk_statusbar_remove_all (GTK_STATUSBAR (ks.statusbar), 1); // Only one context (indicated by 1) with one message.
+    gtk_statusbar_remove_all (GTK_STATUSBAR (ks.statusbar), 1); // Single context (ID 1) with a single message.
     ks.statusbar_msg_shown = FALSE;
 }
 
 /* 
 
-    Helps with the duplication of the original subrows and the adjustment of their visibility status to 
-    their new parent by two steps:
-    1. Creation of arrays of the source row's subrows that include their path depth and expansion status.
-    2. Adjustment of the expansion status of each subrow according to the ones of the source row.
-    The element visibility of all menus, pipe menus, items, and separators
-    of subrows is also adjusted to the one of the destination parent.
+    Assists in duplicating the original subrows and aligning their visibility with the new parent in two steps:
+    1. Builds arrays of the source row’s subrows containing their path depth and expansion state.
+    2. Adjusts each subrow’s expansion state to match the source row.
+    Additionally, sets the element visibility of all menu, pipe menu, item, and separator subrows
+    to match the destination parent.
 
 */
 
@@ -229,7 +228,7 @@ static gboolean subrows_creation_auxiliary (GtkTreeModel  *filter_model,
     g_autoptr(GtkTreePath) model_path;
 
     if (STREQ (g_ptr_array_index (subrows[DD_SUBROWS_ROOT_VISIBILITY], 0), "n/a")) {
-        // --- Step 1: Creation of subrow array(s) ---
+        // --- Step 1: Create subrow array(s) ---
 
         const gint  current_path_depth = gtk_tree_path_get_depth (filter_path);
               gint *max_path_depth = (gint *) subrows[DD_SUBROWS_MAX_PATH_DEPTH][0].pdata;
@@ -246,7 +245,7 @@ static gboolean subrows_creation_auxiliary (GtkTreeModel  *filter_model,
         }
 
         // DD_SUBROWS_EXPANSION_STATUS
-        // The path of the model, not filter model, is needed to check whether the row is expanded.
+        // The model path (not the filter path) is needed to check whether the row is expanded.
         model_path = gtk_tree_model_filter_convert_path_to_child_path ((GtkTreeModelFilter *) filter_model, filter_path);
         g_ptr_array_add (subrows[DD_SUBROWS_EXPANSION_STATUS], 
                          GINT_TO_POINTER (gtk_tree_view_row_expanded (GTK_TREE_VIEW (ks.treeview), model_path)));
@@ -255,12 +254,12 @@ static gboolean subrows_creation_auxiliary (GtkTreeModel  *filter_model,
         g_ptr_array_add (subrows[DD_SUBROWS_CURRENT_PATH_DEPTH], GINT_TO_POINTER (current_path_depth));
     }
     else {
-        // --- Step 2: Adjustment of subrows ---
+        // --- Step 2: Adjust subrows ---
 
         /* --- Step 2a: Expansion status ---
 
-            The path of the model, not filter model, 
-            is needed to set the expansion status and to check if an invisible ancestor exists.
+            Use the model path (not the filter path) to set the expansion state
+            and to check for an invisible ancestor.
 
         */
         model_path = gtk_tree_model_filter_convert_path_to_child_path (GTK_TREE_MODEL_FILTER (filter_model), filter_path);
@@ -271,7 +270,7 @@ static gboolean subrows_creation_auxiliary (GtkTreeModel  *filter_model,
 
         g_ptr_array_remove_index (subrows[DD_SUBROWS_EXPANSION_STATUS], 0);
 
-        // --- Step 2b: Visibilty of menus, pipe menus, items, and separators ---
+        // --- Step 2b: Visibility of menus, pipe menus, items, and separators ---
         g_autofree gchar *element_visibility_txt_filter;
 
         gtk_tree_model_get (filter_model, filter_iter, TS_ELEMENT_VISIBILITY, &element_visibility_txt_filter, -1);
@@ -283,7 +282,7 @@ static gboolean subrows_creation_auxiliary (GtkTreeModel  *filter_model,
         GtkTreeIter model_iter;
         const guint8 invisible_ancestor = check_if_invisible_ancestor_exists (ks.ts_model, model_path);
         gchar *element_visibility_txt_root = g_ptr_array_index (subrows[DD_SUBROWS_ROOT_VISIBILITY], 0);
-        const gchar *new_element_visibility_txt = "visible"; // Default
+        const gchar *new_element_visibility_txt = "visible"; // Default value.
         g_autofree gchar *menu_element_txt_filter, 
                          *type_txt_filter;
 
@@ -311,7 +310,7 @@ static gboolean subrows_creation_auxiliary (GtkTreeModel  *filter_model,
 
 /* 
 
-    Creates a new row at destination and copies all subrows of the source row to it.
+    Creates a new destination row and copy all subrows from the source row.
 
 */
 
@@ -323,10 +322,10 @@ void drag_drop_handler (G_GNUC_UNUSED GtkWidget      *widget,
                         G_GNUC_UNUSED gpointer        user_data)
 {
     GtkTreeViewDropPosition position;
-    gboolean dropped_onto_row = FALSE; // Default
+    gboolean dropped_onto_row = FALSE; // Default value
 
-    gboolean to_be_appended_at_toplevel = FALSE, to_be_appended_as_last_row = FALSE; // Defaults
-    gint insertion_position = 0; // Initialized to avoid compiler warning since this variable might not be used.
+    gboolean to_be_appended_at_toplevel = FALSE, to_be_appended_as_last_row = FALSE; // Default values.
+    gint insertion_position = 0; // Initialized to avoid a compiler warning; this variable may remain unused.
 
     GtkTreeSelection *selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (ks.treeview));
 #if GLIB_CHECK_VERSION(2,56,0)
@@ -336,21 +335,18 @@ void drag_drop_handler (G_GNUC_UNUSED GtkWidget      *widget,
 #endif
     g_autoptr(GtkTreePath) dest_path;
     GtkTreeIter dest_parent_iter;
-    gint dest_path_depth = 0; // Default
+    gint dest_path_depth = 0; // Default value.
     g_autofree gchar *menu_element_dest_parent_txt = NULL, 
                      *type_dest_parent_txt = NULL, 
-                     *element_visibility_parent_txt = NULL; // Defaults
+                     *element_visibility_parent_txt = NULL; // Default values.
 
     GSList *source_paths_loop, *new_rows_loop;
 
+    // If dest_path is NULL, do not abort; it means the row was dragged after the last menu row.
 
     gtk_tree_view_get_dest_row_at_pos (GTK_TREE_VIEW (ks.treeview), x, y, &dest_path, &position);
-    /*
-        If the result is NULL, the function is not aborted, since the result indicates 
-        that the row has been dragged after the last row of the menu.
-    */ 
 
-     // Don't continue if the source rows are dropped onto themselves.
+    // Do not continue if the source rows are dropped onto themselves.
     if (dest_path) {
         FOREACH_IN_LIST (ks.source_paths, source_paths_loop) {
             g_autoptr(GtkTreePath) source_path_loop = gtk_tree_row_reference_get_path (source_paths_loop->data);
@@ -424,7 +420,7 @@ void drag_drop_handler (G_GNUC_UNUSED GtkWidget      *widget,
 
         gboolean source_row_has_child = gtk_tree_model_iter_has_child (ks.ts_model, &source_iter);
         // Retrieve data of the subrows of the source row, if they exist.
-        if (source_row_has_child) { // Parentheses avoid gcc warning.
+        if (source_row_has_child) {
             for (subrows_elm_cnt = 0; subrows_elm_cnt < DD_NUMBER_OF_SUBROW_ELEMENTS; ++subrows_elm_cnt) {
                 subrows[subrows_elm_cnt] = g_ptr_array_new ();
             }
@@ -439,12 +435,12 @@ void drag_drop_handler (G_GNUC_UNUSED GtkWidget      *widget,
         }
 
         /*
-            If a menu, pipe menu, item or separator is dragged into a menu, 
-            its element visibility is set according to the one of the latter. 
-            If dragged to toplevel, the element visiblity is adjusted as well.
+            When a menu, pipe menu, item, or separator is dragged into a menu,
+            set its element visibility to match the destination.
+             If dragged to the top level, adjust the element visibility accordingly.
         */
         if (!type_dest_parent_txt || STREQ (type_dest_parent_txt, "menu")) {
-            const gchar *new_element_visibility_txt = "visible"; // Default
+            const gchar *new_element_visibility_txt = "visible"; // Default value.
 
             if (G_LIKELY (!element_visibility_parent_txt || STREQ (element_visibility_parent_txt, "visible"))) {
                 if (G_UNLIKELY (!element_visibility_parent_txt && 
@@ -484,9 +480,9 @@ void drag_drop_handler (G_GNUC_UNUSED GtkWidget      *widget,
         g_autoptr(GtkTreePath) new_path = gtk_tree_model_get_path (ks.ts_model, &new_iter);
 
         /*
-            The new rows list has to consist of row references, since a dragged row might be an option which is sorted 
-            after the insertion if autosorting is enabled and thus might change the path of other inserted options which 
-            have to be sorted next.
+		    The list must contain row references, because a dragged option may be sorted
+			after insertion (when autosorting is enabled), which can change the paths
+			of subsequently inserted options that still need sorting.
         */
         new_rows = g_slist_prepend (new_rows, gtk_tree_row_reference_new (ks.ts_model, new_path));
 
@@ -517,12 +513,12 @@ void drag_drop_handler (G_GNUC_UNUSED GtkWidget      *widget,
                 }
             }
 
-            // If the source row was a node that was expanded, expand the new row as well.
+            // If the source row was expanded, expand the new row as well.
             if (expand_new_row) {
                 gtk_tree_view_expand_row (GTK_TREE_VIEW (ks.treeview), new_path, FALSE);
             }
 
-            // Set expansions status of all subrows, and also element visibility for all menus, pipe menus, items, and separators.
+            // Set the expansion status of all subrows and adjust element visibility for all menus, pipe menus, items, and separators.
             g_ptr_array_index (subrows[DD_SUBROWS_ROOT_VISIBILITY], 0) = copied_ts_row_fields[TS_ELEMENT_VISIBILITY];
 
             g_autoptr(GtkTreeModel) filter_model = gtk_tree_model_filter_new (ks.ts_model, new_path);
@@ -544,21 +540,21 @@ void drag_drop_handler (G_GNUC_UNUSED GtkWidget      *widget,
         }
     }
 
-    // The source rows are still selected, so they may be deleted that simple.
+    // The source rows are still selected, so they can be deleted directly.
     remove_rows ("dnd");
 
-    g_signal_handler_block (selection, ks.handler_id_row_selected); // Deactivates unnecessary selection check.
+    g_signal_handler_block (selection, ks.handler_id_row_selected); // Disable unnecessary selection checks.
 
     /* 
-        This prevents a possible block of the change of the selection of nodes if 
-        the to be dragged nodes had been clicked on again before dragging.
+        Prevent selection-change blocking when the nodes to be dragged
+        were clicked again immediately before dragging.
     */
     gtk_tree_selection_set_select_function (gtk_tree_view_get_selection (GTK_TREE_VIEW (ks.treeview)), 
                                             (GtkTreeSelectionFunc) selection_block_unblock, GINT_TO_POINTER (TRUE), NULL);
 
     /*
-        Select the new root row(s). If these rows are options or option blocks that have been moved elsewhere and 
-        autosorting is activated, sort the options resp. option block.
+        Select the new root row(s). If they are options or option blocks moved elsewhere
+        and autosorting is enabled, sort the options/option block.
     */
     gtk_tree_selection_unselect_all (selection);
 
@@ -569,10 +565,9 @@ void drag_drop_handler (G_GNUC_UNUSED GtkWidget      *widget,
         gtk_tree_model_get_iter (ks.ts_model, &ks.iter, new_path);
         gtk_tree_model_get (ks.ts_model, &ks.iter, TS_TYPE, &type_new_row_txt, -1);
         /*
-            If the inserted row is an option or option block and the number of children of the parent action/option block 
-            (=all options that currently exist inside the current parent) > 1, then the new row is always an option 
-            of "Execute" or an option of "startupnotify", since only an "Execute" action or a "startupnotify" option block 
-            can have more than one child.
+		    If the inserted row is an option or option block and the parent action/option block
+			now has more than one child, the new row must be an option of "Execute" or of "startupnotify",
+		    since only those can have multiple children.
         */
         if (ks.settings.autosort_options && streq_any (type_new_row_txt, "option", "option block", NULL) && 
             gtk_tree_model_iter_n_children (ks.ts_model, &dest_parent_iter) > 1) {
