@@ -20,8 +20,8 @@
 #include <gtk/gtk.h>
 
 #include <setjmp.h>
-#include <stdlib.h> // Sometimes this might have to be included explicitly.
-#include <string.h> // Sometimes this might have to be included explicitly.
+#include <stdlib.h> // May need to be included explicitly in some environments.
+#include <string.h> // May need to be included explicitly in some environments.
 
 #include "declarations_definitions_and_enumerations.h"
 #include "save_menu.h"
@@ -38,7 +38,7 @@ typedef struct {
     gchar *save_txts[NUMBER_OF_TXT_FIELDS];
 } SaveMenuArgsData;
 
-// SM = Save Menu, indicating that the enums are only used here.
+// SM = Save Menu; these enums are only used in this file.
 enum { SM_MENUS, SM_ROOT_MENU, SM_IND_OF_SAVING_STAGE, SM_NO_SEPARATE_ROOT_MENU };
 enum { SM_TOPLEVEL, SM_FILTER_LEVEL, SM_IND_OF_LEVEL };
 enum { SM_MENU_OR_PIPE_MENU, SM_ITEM_OR_ACTION, SM_SEPARATOR };
@@ -89,10 +89,10 @@ static gboolean closing_tags (const gboolean          filter_iteration_completed
     const gchar *indentation = (ks.settings.tabs_for_indentations) ? "\t" : "    ";
 
     /*
-        The number of indentations for elements outside and inside the root menu differs.
-        A menu with the menu ID "root_menu" has to be written, into which all root elements are packed.
-        Since the root menu itself is not visualized inside the tree view, there has to be an additional
-        indentation written into the menu file for all those elements.
+        The number of indentations differs for elements inside and outside the root menu.
+        A menu with the ID "root_menu" must be written to contain all root elements.
+        Since the root menu itself is not shown in the tree view, all of its elements
+        require one additional indentation level in the menu file.
 
         --- MENU DEFINITIONS ---
 
@@ -120,8 +120,8 @@ static gboolean closing_tags (const gboolean          filter_iteration_completed
     gchar *ts_txt[SM_NUMBER_OF_ITER_ARRAY_ELM][2]; // COL_MENU_ELEMENT & COL_TYPE for current and previous iter.
 
     /* 
-        action_closing_tag_subtraction contains the number of indentations 
-        that have to be removed for the closing action tag after the last option of an action.
+        action_closing_tag_subtraction specifies how many indentation levels to remove
+        when writing the closing </action> tag after the last option of an action.
 
         1 = option of action (='command' and 'prompt')
         <item label="Program">
@@ -152,10 +152,10 @@ static gboolean closing_tags (const gboolean          filter_iteration_completed
         <item label="New item"> 
         ...
   
-        action_closing_tag_subtraction defaults to -1. This is done for the case that additional </menu> 
-        closing tags have to be added. The reason for setting the default value to -1 is explained there.
+        Defaults to -1 for the case where extra </menu> closing tags are needed.
+        The reason for using -1 is explained where those extra tags are added.
     */
-    gint8 action_closing_tag_subtraction = -1; // Default
+    gint8 action_closing_tag_subtraction = -1; // Default value.
 
     gint path_depth_prev_cnt, subtr_path_depth_prev_cnt;
     gint8 array_cnt;
@@ -206,11 +206,14 @@ static gboolean closing_tags (const gboolean          filter_iteration_completed
         (streq_any (ts_txt[SM_CURRENT][COL_TYPE], "menu", "pipe menu", "item", "separator", NULL) || 
         filter_iteration_completed)) {
         /* 
-            If an open action has been closed (or it has been a self-closing action) and no new action follows, 
-            an </item> tag is written.
-            The calculation of the subtraction for this tag is  
-             filter_path_depth_prev - action_closing_tag_subtraction - 1, 
-            since the </item> closing tag is one indentation level below the one of the </action> closing tag:
+            If an open action has been closed (or it was self-closing) and no new action follows,
+            write a closing </item> tag.
+
+            The indentation is calculated as:
+            filter_path_depth_prev - action_closing_tag_subtraction - 1
+
+            since </item> is one level less indented than </action>.
+
             Either 
 
                     <prompt>yes</prompt> (example)
@@ -239,6 +242,7 @@ static gboolean closing_tags (const gboolean          filter_iteration_completed
         const gint filter_path_depth = (filter_iteration_completed) ? 1 : gtk_tree_path_get_depth (filter_path);
 
         /* 
+        
             If the current element is a menu, pipe menu, item or separator or the filter iteration has been completed and 
             the current path depth is lower than the previous one, addtional </menu> tags have to be added, 
             as for example in these cases:
@@ -281,23 +285,31 @@ static gboolean closing_tags (const gboolean          filter_iteration_completed
             2 < filter_path_depth_prev (=3, 'separator') - action_closing_tag_substraction (here: -1) - 1 -> 2 < 3
             3 - 2 = 1 closing tag to write.
 
-            If the current element is a menu/pipe menu/item/separator or the filter iteration has been completed, 
-            its path depth is compared to the one of the previous element. If the path depth of the current element is 
-            lower than the one of the previous element, there are still open menu tags and additional </menu> tags have to 
-            be written until the level of the current element or, in the case of a last row, the base level.
-            If the previous element is an option of an action or a self-closing action, the value of the previous path depth 
-            has to be adjusted to the additional closing tags resulting from this, since there have to be written less 
-            </menu> closing tags then. 
-            For this case the action_closing_tag_substraction variable has been set above, and considering there is also 
-            a closing item tag following afterwards, the calculation is 
-            filter_path_depth_prev - action_closing_tag_subtraction - 1 
-             (see above for the values for action_closing_tag subtraction). 
-            If the previous element is not an option of an action or self-closing action, 
-             but a self-closing menu/item, a pipe menu or separator, there is not only no action closing tag subtraction, 
-            but the additional reduction for the closing item tag has also to be taken to account. 
-            That is why action_closing_tag_subtraction defaults to -1 for this case, since this evaluates to    
+            If the current element is a menu, pipe menu, item, separator, or the filter iteration has completed, 
+            its path depth is compared to that of the previous element. 
+
+            If the current element’s path depth is lower than the previous one, there are still open <menu> tags. 
+            Additional </menu> tags must be written until reaching the level of the current element or, if it is the last row, the base level.
+
+            If the previous element is an option of an action or a self-closing action, 
+            the previous path depth must be adjusted to account for the extra closing tags these elements produce. 
+            In this case, fewer </menu> tags need to be written. 
+            The `action_closing_tag_subtraction` variable (set above) stores this adjustment. 
+            Because a closing </item> tag follows afterward, the calculation is:
+
+            filter_path_depth_prev - action_closing_tag_subtraction - 1
+
+            (See above for the values assigned to `action_closing_tag_subtraction`.)
+
+            If the previous element is not an option of an action or a self-closing action, 
+            but instead a self-closing menu/item, pipe menu, or separator, there is no action closing tag subtraction. 
+            The extra reduction for the closing </item> tag must still be applied. 
+            For this reason, `action_closing_tag_subtraction` defaults to –1 in this case, which yields:
+
             filter_path_depth_prev - (-1) - 1 = filter_path_depth_prev
-            so reductions that would be caused by additional closing tags don't come to effect.
+
+            This way, any reductions that would otherwise be caused by extra closing tags are neutralized.
+
         */
         if ((streq_any (ts_txt[SM_CURRENT][COL_TYPE], "menu", "pipe menu", "item", "separator", NULL) || 
             filter_iteration_completed) && 
@@ -338,12 +350,14 @@ static gboolean closing_tags (const gboolean          filter_iteration_completed
     return (*error == NULL);
 }
 
-/* 
 
-    Writes an (opening) menu, item, separator or action tag into the menu XML file.
+/*
+    
+    Writes an (opening) menu, item, separator, or action tag into the menu XML file.
 
 */
 
+
 static void write_tag (const guint8             saving_stage, 
                        const guint8             level, 
                              gchar            **tag_elements, 
@@ -353,14 +367,15 @@ static void write_tag (const guint8             saving_stage,
                              SaveMenuArgsData  *save_menu_args)
 {
     GOutputStream *menu_file_output_stream = save_menu_args->menu_file_output_stream;
-    GError **error = save_menu_args->error;
+    GError **error = save_menu_args->error;  
     /*
-        For actions and options there is no distinction made between SM_MENUS and SM_ROOT_MENU, 
-        the value is always SM_IND_OF_SAVING_STAGE. 
-        If the current saving stage is SM_ROOT_MENU and a menu or item has to be written, this function was called 
-        directly from the save_menu and not from the treestore_save_process_iteration function.
-        This means that there has no indentation been done yet (this is done inside the latter function), 
-        so there's one added for the mentioned case.
+        For actions and options, there is no distinction between SM_MENUS and SM_ROOT_MENU;
+        the value is always SM_IND_OF_SAVING_STAGE.
+
+        If saving_stage == SM_ROOT_MENU and the element is a menu or item,
+        this function was called directly from save_menu (not from treestore_save_process_iteration).
+        In this case, indentation has not yet been applied (it’s normally handled in the latter),
+        so one indentation level is added here.
     */
     const gchar *indentation = (ks.settings.tabs_for_indentations) ? "\t" : "    ";
     g_autoptr(GString) file_string = g_string_new ((saving_stage == SM_ROOT_MENU || 
@@ -420,7 +435,7 @@ static void write_tag (const guint8             saving_stage,
 
 /* 
 
-    Gets all values of a row needed for saving and escapes their special characters.
+    Gets all required values from a row for saving and escapes special characters.
 
 */
 
@@ -436,10 +451,10 @@ static void get_field_values (gchar        **txt_fields_array,
     }
 }
 
-/* 
+/*
 
-    Iterates through the elements of a menu or item for processing 
-    of each node and generating lines for the xml file.
+    Iterates through the elements of a menu or item,
+    processing each node and generating lines for the XML file.
 
 */
 
@@ -468,12 +483,12 @@ static gboolean treestore_save_process_iteration (GtkTreeModel     *filter_model
     get_field_values (save_txts, filter_model, filter_iter);
 
     /*
-        Create leading whitespace for indenting.
+        Create leading whitespace for indentation.
 
-        The number of indentations for elements outside and inside the root menu differs.
-        A menu with the menu ID "root_menu" has to be written, into which all root elements are packed.
-        Since the root menu itself is not visualized inside the tree view, there has to be an additional indentation 
-        written into the menu file for all those elements.
+        The number of indentations differs for elements inside and outside the root menu.
+        A menu with the ID "root_menu" must be written to contain all root elements.
+        Since the root menu itself is not shown in the tree view, all of its elements
+        require one additional indentation level in the menu file.
 
         --- MENU DEFINITIONS ---
 
@@ -552,7 +567,7 @@ static gboolean treestore_save_process_iteration (GtkTreeModel     *filter_model
     return (*error != NULL); // FALSE = continue iterating.
 }
 
-/* 
+/*
 
     Processes all subrows of a menu or item.
 
@@ -585,11 +600,14 @@ static void process_menu_or_item (GtkTreeIter      *process_iter,
 
 /*
 
-    If a menu that contained invisible orphaned menus is saved with the "Keep Root Menu Separate in Saved Menu File" being disabled, 
-    this filter callback function renders the children of such menus visible, provided that they have a label. 
-    If they don't have a label, child menus, pipe menus, and items will remain invisible and are marked as such. The same applies 
-    if a previously invisible orphaned menu didn't have a label; it is now no longer orphaned, but due to the missing label it 
-    remains invisible.
+    If a menu that contained invisible orphaned menus is saved with
+    “Keep Root Menu Separate in Saved Menu File” disabled,
+    this filter callback function makes the children of such menus visible,
+    provided they have a label.
+
+    If they lack a label, child menus, pipe menus, and items remain invisible
+    and are marked as such. The same applies if a previously invisible orphaned menu
+    has no label—although it is no longer orphaned, the missing label keeps it invisible.
 
 */
 
@@ -680,8 +698,8 @@ void save_menu (gchar *save_as_filename)
         // If save_menu is called directly, save_as_filename is NULL, thus g_free () will do effectively nothing.
         g_free (save_as_filename);
         /*
-            Either the elemets of the string arrays have a value and can thus be freed, 
-            or they don't and are set to NULL, which means that these functions do effectively nothing.
+            Either the elements of the string arrays contain a value and can be freed,
+            or they are NULL, in which case these functions effectively do nothing.
         */
         free_elements_of_static_string_array (save_txts_toplevel, NUMBER_OF_TXT_FIELDS, FALSE);
         free_elements_of_static_string_array (save_menu_args.save_txts, NUMBER_OF_TXT_FIELDS, FALSE);
@@ -702,7 +720,7 @@ void save_menu (gchar *save_as_filename)
     }
 
     if (ks.settings.separate_root_menu) {
-        gboolean at_least_one_menu_before_the_root_menu_written = FALSE; // Default
+        gboolean at_least_one_menu_before_the_root_menu_written = FALSE; // Default value.
 
         // Menus
         valid = gtk_tree_model_get_iter_first (ks.ts_model, &save_menu_iter);
@@ -819,8 +837,10 @@ void save_menu (gchar *save_as_filename)
         set_filename_and_window_title (save_as_filename);
     }
 
-    /* The stream has to be closed manually before reconfiguring Openbox, 
-       otherwise the reconfiguration occasionally won't work. */ 
+    /* 
+        The stream must be closed manually before reconfiguring Openbox,
+        otherwise the reconfiguration may occasionally fail.
+    */
     if (G_UNLIKELY (!g_output_stream_close (G_OUTPUT_STREAM (menu_file_output_stream), NULL, &error))) {
         longjmp (buf, 1);
     }
@@ -855,12 +875,16 @@ void save_menu (gchar *save_as_filename)
     }
 
     if (!(ks.settings.separate_root_menu)) {
-        gboolean invisible_orphaned_menu_has_been_converted_to_visible = FALSE; // Default
+        gboolean invisible_orphaned_menu_has_been_converted_to_visible = FALSE; // Default value.
 
-        /* Invisible orphaned menus are placed at the bottom by default, so it would be conventient to start from 
-           there and iterate to the top. However, since there is no gtk_tree_model_get_iter_last() (at least as 
-           public function), the program starts from the top. This is hardly slowing down the program though, 
-           because the iteration is only done over top level menu elements. */
+        /*
+           Invisible orphaned menus are placed at the bottom by default,
+           so it would be convenient to iterate from the bottom to the top.
+           However, since there is no public gtk_tree_model_get_iter_last(),
+           iteration starts from the top.
+
+           This has negligible performance impact because only top-level menu elements are processed.
+        */
         valid = gtk_tree_model_get_iter_first (ks.ts_model, &save_menu_iter);
         while (valid) {
             get_field_values (save_txts_toplevel, ks.ts_model, &save_menu_iter);
@@ -897,8 +921,11 @@ void save_menu (gchar *save_as_filename)
         }
     }
 
-    /* If the file is saved to the standard path .config/openbox/menu.xml, Kickshaw will open this file 
-       automatically after a restart. It is thus not necessary to keep an autosave after saving in this case. */    
+    /*
+       If the file is saved to the standard path .config/openbox/menu.xml,
+       Kickshaw will automatically open it after a restart.
+       In this case, keeping an autosave is unnecessary.
+    */
     if (G_LIKELY (g_regex_match_simple (".*\\.config/openbox/menu\\.xml$", ks.filename, 0, 0))) {
         delete_autosave ();
     }
@@ -921,9 +948,9 @@ void save_menu (gchar *save_as_filename)
     row_selected ();
 }
 
-/* 
+/*
 
-    Asks for a file name prior to saving.
+    Asks for a file name before saving.
 
 */
 
