@@ -19,8 +19,8 @@
 
 #include <gtk/gtk.h>
 
-#include <stdlib.h> // Sometimes this might have to be included explicitly.
-#include <string.h> // Sometimes this might have to be included explicitly.
+#include <stdlib.h> // May need to be included explicitly in some environments.
+#include <string.h> // May need to be included explicitly in some environments.
 
 #include "declarations_definitions_and_enumerations.h"
 #include "undo_redo_autosave.h"
@@ -38,8 +38,8 @@ static gboolean write_row_information (GtkTreeModel  *model,
 
 /*
 
-    Shows a message related to an error that occurred during the creation or writing 
-    of a new undo stack item and resets the position index, if applicable.
+    Shows a message about an error that occurred while creating or writing
+    a new undo stack item, and resets the position index if applicable.
 
 */
 
@@ -67,12 +67,11 @@ static void show_errmsg_and_restore_position_index (const gchar  *action,
     show_errmsg (err_msg);
 }
 
-/* 
+/*
 
-    Writes everything relevant needed to restore the data and appearance of a single tree view row, including:
-    - Tree store fields (of the image related fields, only the file path is used, 
-      since there might have occurred changes to the image file in the time between the storage of the data 
-      and its retrieval).
+    Writes all relevant data needed to restore the content and appearance of a single tree view row, including:
+    - Tree store fields (of the image-related fields, only the file path is stored,
+      because the image file might have changed between saving and restoring).
     - Existence of a label
     - Path depth
     - Selection status
@@ -125,10 +124,10 @@ static gboolean write_row_information (GtkTreeModel  *model,
     return (error != NULL); // TRUE = stop iterating.
 }
 
-/* 
+/*
 
-    Pushes tree view data on the undo stack, 
-    i.e. writes this data into a compressed file inside the tmp folder.
+    Pushes the tree view data onto the undo stack
+    by writing it to a compressed file in the tmp folder.
 
 */
 
@@ -244,10 +243,9 @@ void push_new_item_on_undo_stack (const gboolean after_save)
     write_autosave (compressed_undo_file);
 }
 
-/* 
-
-    Undos the last or redos the next change from the current position inside the undo stack. Also restores an autosave.
-
+/*
+    Undoes the last change or redoes the next change from the current undo stack position.
+    Also restores an autosave if requested.
 */
 
 void undo_redo_restore (const gchar *action)
@@ -328,7 +326,7 @@ void undo_redo_restore (const gchar *action)
     GSList *selected_paths = NULL;
 #endif
 
-    guint max_path_depth = 1; // Default
+    guint max_path_depth = 1; // Default value.
 
     // x1E (dec. 30) = record/row separator
     while (g_input_stream_read (decom_undo_file_input_stream, buffer, 1, NULL, &error) > 0 && !(STREQ (buffer, "\x1E"))) { 
@@ -504,8 +502,8 @@ void undo_redo_restore (const gchar *action)
 
 /*
 
-    Creates a symbolic link to the undo stack file that indicates the current position inside the stack.
-    Meant for use after a restart or an irregular termination of the program.
+    Creates a symbolic link to the undo stack file representing the current position.
+    Intended for use after a restart or irregular termination of the program.
 
 */
 
@@ -558,7 +556,8 @@ void write_autosave (GFile *compressed_undo_file)
 
 /*
 
-    Called after copying of the latest undo stack item as autosave is finished to check for errors.
+    Called after the latest undo stack item has been copied as an autosave,
+    to check for errors.
 
 */
 
